@@ -5,11 +5,11 @@ context("etl")
 
 test_that("sqlite works", {
   cars_sqlite <- etl("mtcars")
-  expect_s3_class(cars_sqlite, c("etl_mtcars", "etl", "src_sqlite", "src_sql"))
+  expect_s3_class(cars_sqlite, c("etl_mtcars", "etl", "src_sqlite", "src_dbi"))
   expect_true(file.exists(find_schema(cars_sqlite)))
-  expect_message(find_schema(cars, "my_crazy_schema", "etl"))
+  expect_message(find_schema(cars_sqlite, "my_crazy_schema", "etl"))
   expect_output(summary(cars_sqlite), "files")
-  expect_message(cars_sqlite %>% etl_create(), "success")
+  expect_message(cars_sqlite %>% etl_create(), "Uploading")
   expect_message(cars_sqlite %>% etl_init(), "Loading SQL script")
   expect_message(
     cars_sqlite %>% etl_cleanup(delete_raw = TRUE, delete_load = TRUE),
@@ -18,11 +18,11 @@ test_that("sqlite works", {
 
 test_that("dplyr works", {
   expect_message(cars <- etl("mtcars") %>%
-    etl_create(), regexp = "success")
+    etl_create(), regexp = "Uploading")
   expect_gt(length(src_tbls(cars)), 0)
   tbl_cars <- cars %>%
      tbl("mtcars")
-  expect_s3_class(tbl_cars, "tbl_sqlite")
+  expect_s3_class(tbl_cars, "tbl_dbi")
   expect_s3_class(tbl_cars, "tbl_sql")
   res <- tbl_cars %>%
     collect()
@@ -30,7 +30,7 @@ test_that("dplyr works", {
   # double up the data
   expect_message(
     cars %>%
-      etl_update(), regexp = "success")
+      etl_update(), regexp = "Uploading")
   res2 <- tbl_cars %>%
     collect()
   expect_equal(nrow(res2), 2 * nrow(mtcars))
@@ -40,30 +40,15 @@ test_that("dplyr works", {
 test_that("mysql works", {
   if (require(RMySQL) && mysqlHasDefault()) {
     db <- src_mysql_cnf()
-    expect_s3_class(db, "src_mysql")
+    expect_s3_class(db, "src_dbi")
     cars_mysql <- etl("mtcars", db = db)
-    expect_s3_class(cars_mysql, c("etl_mtcars", "etl", "src_mysql", "src_sql"))
+    expect_s3_class(cars_mysql, c("etl_mtcars", "etl", "src_dbi", "src_dbi"))
     expect_true(file.exists(find_schema(cars_mysql)))
-    expect_message(find_schema(cars, "my_crazy_schema", "etl"))
+    expect_message(find_schema(cars_mysql, "my_crazy_schema", "etl"))
     expect_output(summary(cars_mysql), "/tmp")
   }
 })
 
-test_that("MonetDBLite works", {
-  if (require(MonetDBLite)) {
-    db <- MonetDBLite::src_monetdblite()
-    cars_monet <- etl("mtcars", db = db)
-    expect_message(
-      cars_monet %>%
-        etl_create()
-    )
-    tbl_cars <- cars_monet %>%
-      tbl("mtcars")
-    expect_equal(nrow(tbl_cars %>% collect()), 32)
-    expect_s3_class(cars_monet, "src_monetdb")
-    expect_s3_class(tbl_cars, "tbl_monetdb")
-  }
-})
 
 test_that("valid_year_month works", {
   expect_equal(
@@ -99,6 +84,31 @@ test_that("etl works", {
 
 test_that("smart_download works", {
   cars <- etl("mtcars")
-  urls <- c("http://www.google.com", "http://www.nytimes.com")
-  expect_length(smart_download(cars, src = urls), 2)
+  # first download some files
+#  if (!.Platform$OS.type == "windows") {
+    urls <- c("https://raw.githubusercontent.com/beanumber/etl/master/etl.Rproj",
+              "https://www.reddit.com/robots.txt")
+    expect_length(smart_download(cars, src = urls), 2)
+    # then try to download them again
+    expect_length(list.files(attr(cars, "raw_dir")), 3)
+    expect_length(smart_download(cars, src = urls), 0)
+    expect_message(etl_cleanup(cars, pattern = "com", delete_raw = TRUE), "Deleting")
+#  }
+})
+
+
+test_that("MonetDBLite works", {
+  if (require(MonetDBLite)) {
+    # db <- MonetDBLite::src_monetdblite()
+    # cars_monet <- etl("mtcars", db = db)
+    # expect_message(
+    #   cars_monet %>%
+    #     etl_create()
+    # )
+    # tbl_cars <- cars_monet %>%
+    #   tbl("mtcars")
+    # expect_equal(nrow(tbl_cars %>% collect()), 32)
+    # expect_s3_class(cars_monet, "src_monetdb")
+    # expect_s3_class(tbl_cars, "tbl_monetdb")
+  }
 })
